@@ -30,6 +30,10 @@
 #include <errno.h>
 #include <libintl.h>
 
+#if HAS_LIBCPUID
+# include <libcpuid/libcpuid.h>
+#endif
+
 /* Software definition */
 #define PRGNAME               "CPU-X"
 #define PRGNAME_LOW           "cpu-x"
@@ -87,7 +91,7 @@
 #define MAXSTR                80       /* Max string */
 #define CACHEFIELDS           2        /* Nb of fields by cache frame */
 #define RAMFIELDS             2        /* Nb of fields by bank */
-#define GPUFIELDS             15       /* Nb of fields by GPU frame */
+#define GPUFIELDS             20       /* Nb of fields by GPU frame */
 #define BENCHFIELDS           2        /* Nb of fields by bench frame */
 
 #define UNIT_B                _("bytes")
@@ -150,7 +154,7 @@ enum EnTabCpu
 	VENDOR, CODENAME, PACKAGE, TECHNOLOGY, VOLTAGE, SPECIFICATION, FAMILY, EXTFAMILY, MODEL, EXTMODEL, TEMPERATURE, STEPPING, INSTRUCTIONS,
 	CORESPEED, MULTIPLIER, BUSSPEED, USAGE,
 	LEVEL1D, LEVEL1I, LEVEL2, LEVEL3,
-	SOCKETS, CORES, THREADS,
+	CORES, THREADS,
 	LASTCPU
 };
 
@@ -193,14 +197,14 @@ enum EnTabSystemExtra
 
 enum EnTabGraphics
 {
-	GPU1VENDOR, GPU1DRIVER, GPU1UMD, GPU1MODEL, GPU1CU, GPU1DIDRID, GPU1PCIE, GPU1TEMPERATURE, GPU1USAGE, GPU1VOLTAGE, GPU1POWERAVG, GPU1CORECLOCK, GPU1MEMCLOCK, GPU1MEMUSED, GPU1REBAR,
-	GPU2VENDOR, GPU2DRIVER, GPU2UMD, GPU2MODEL, GPU2CU, GPU2DIDRID, GPU2PCIE, GPU2TEMPERATURE, GPU2USAGE, GPU2VOLTAGE, GPU2POWERAVG, GPU2CORECLOCK, GPU2MEMCLOCK, GPU2MEMUSED, GPU2REBAR,
-	GPU3VENDOR, GPU3DRIVER, GPU3UMD, GPU3MODEL, GPU3CU, GPU3DIDRID, GPU3PCIE, GPU3TEMPERATURE, GPU3USAGE, GPU3VOLTAGE, GPU3POWERAVG, GPU3CORECLOCK, GPU3MEMCLOCK, GPU3MEMUSED, GPU3REBAR,
-	GPU4VENDOR, GPU4DRIVER, GPU4UMD, GPU4MODEL, GPU4CU, GPU4DIDRID, GPU4PCIE, GPU4TEMPERATURE, GPU4USAGE, GPU4VOLTAGE, GPU4POWERAVG, GPU4CORECLOCK, GPU4MEMCLOCK, GPU4MEMUSED, GPU4REBAR,
-	GPU5VENDOR, GPU5DRIVER, GPU5UMD, GPU5MODEL, GPU5CU, GPU5DIDRID, GPU5PCIE, GPU5TEMPERATURE, GPU5USAGE, GPU5VOLTAGE, GPU5POWERAVG, GPU5CORECLOCK, GPU5MEMCLOCK, GPU5MEMUSED, GPU5REBAR,
-	GPU6VENDOR, GPU6DRIVER, GPU6UMD, GPU6MODEL, GPU6CU, GPU6DIDRID, GPU6PCIE, GPU6TEMPERATURE, GPU6USAGE, GPU6VOLTAGE, GPU6POWERAVG, GPU6CORECLOCK, GPU6MEMCLOCK, GPU6MEMUSED, GPU6REBAR,
-	GPU7VENDOR, GPU7DRIVER, GPU7UMD, GPU7MODEL, GPU7CU, GPU7DIDRID, GPU7PCIE, GPU7TEMPERATURE, GPU7USAGE, GPU7VOLTAGE, GPU7POWERAVG, GPU7CORECLOCK, GPU7MEMCLOCK, GPU7MEMUSED, GPU7REBAR,
-	GPU8VENDOR, GPU8DRIVER, GPU8UMD, GPU8MODEL, GPU8CU, GPU8DIDRID, GPU8PCIE, GPU8TEMPERATURE, GPU8USAGE, GPU8VOLTAGE, GPU8POWERAVG, GPU8CORECLOCK, GPU8MEMCLOCK, GPU8MEMUSED, GPU8REBAR,
+	GPU1VENDOR, GPU1DRIVER, GPU1UMD, GPU1MODEL, GPU1CU, GPU1DIDRID, GPU1VBIOS, GPU1PCIE, GPU1TEMPERATURE, GPU1USAGE, GPU1VOLTAGE, GPU1POWERAVG, GPU1CORECLOCK, GPU1MEMCLOCK, GPU1MEMUSED, GPU1REBAR, GPU1VKRT, GPU1GLVER, GPU1VKVER, GPU1CLVER,
+	GPU2VENDOR, GPU2DRIVER, GPU2UMD, GPU2MODEL, GPU2CU, GPU2DIDRID, GPU2VBIOS, GPU2PCIE, GPU2TEMPERATURE, GPU2USAGE, GPU2VOLTAGE, GPU2POWERAVG, GPU2CORECLOCK, GPU2MEMCLOCK, GPU2MEMUSED, GPU2REBAR, GPU2VKRT, GPU2GLVER, GPU2VKVER, GPU2CLVER,
+	GPU3VENDOR, GPU3DRIVER, GPU3UMD, GPU3MODEL, GPU3CU, GPU3DIDRID, GPU3VBIOS, GPU3PCIE, GPU3TEMPERATURE, GPU3USAGE, GPU3VOLTAGE, GPU3POWERAVG, GPU3CORECLOCK, GPU3MEMCLOCK, GPU3MEMUSED, GPU3REBAR, GPU3VKRT, GPU3GLVER, GPU3VKVER, GPU3CLVER,
+	GPU4VENDOR, GPU4DRIVER, GPU4UMD, GPU4MODEL, GPU4CU, GPU4DIDRID, GPU4VBIOS, GPU4PCIE, GPU4TEMPERATURE, GPU4USAGE, GPU4VOLTAGE, GPU4POWERAVG, GPU4CORECLOCK, GPU4MEMCLOCK, GPU4MEMUSED, GPU4REBAR, GPU4VKRT, GPU4GLVER, GPU4VKVER, GPU4CLVER,
+	GPU5VENDOR, GPU5DRIVER, GPU5UMD, GPU5MODEL, GPU5CU, GPU5DIDRID, GPU5VBIOS, GPU5PCIE, GPU5TEMPERATURE, GPU5USAGE, GPU5VOLTAGE, GPU5POWERAVG, GPU5CORECLOCK, GPU5MEMCLOCK, GPU5MEMUSED, GPU5REBAR, GPU5VKRT, GPU5GLVER, GPU5VKVER, GPU5CLVER,
+	GPU6VENDOR, GPU6DRIVER, GPU6UMD, GPU6MODEL, GPU6CU, GPU6DIDRID, GPU6VBIOS, GPU6PCIE, GPU6TEMPERATURE, GPU6USAGE, GPU6VOLTAGE, GPU6POWERAVG, GPU6CORECLOCK, GPU6MEMCLOCK, GPU6MEMUSED, GPU6REBAR, GPU6VKRT, GPU6GLVER, GPU6VKVER, GPU6CLVER,
+	GPU7VENDOR, GPU7DRIVER, GPU7UMD, GPU7MODEL, GPU7CU, GPU7DIDRID, GPU7VBIOS, GPU7PCIE, GPU7TEMPERATURE, GPU7USAGE, GPU7VOLTAGE, GPU7POWERAVG, GPU7CORECLOCK, GPU7MEMCLOCK, GPU7MEMUSED, GPU7REBAR, GPU7VKRT, GPU7GLVER, GPU7VKVER, GPU7CLVER,
+	GPU8VENDOR, GPU8DRIVER, GPU8UMD, GPU8MODEL, GPU8CU, GPU8DIDRID, GPU8VBIOS, GPU8PCIE, GPU8TEMPERATURE, GPU8USAGE, GPU8VOLTAGE, GPU8POWERAVG, GPU8CORECLOCK, GPU8MEMCLOCK, GPU8MEMUSED, GPU8REBAR, GPU8VKRT, GPU8GLVER, GPU8VKVER, GPU8CLVER,
 	LASTGRAPHICS
 };
 
@@ -249,8 +253,10 @@ enum EnMultipliers
 
 typedef struct
 {
-	int8_t  cpu_vendor_id;
-	int32_t cpu_model, cpu_ext_model, cpu_ext_family;
+	bool change_type;
+#if HAS_LIBCPUID
+	struct system_id_t system_id;
+#endif /* HAS_LIBCPUID */
 	char *cpuid_raw_file;
 } LibcpuidData;
 
@@ -299,7 +305,8 @@ typedef struct
 	char *tab_about[LASTABOUT];
 
 	int     cpu_freq, socket_fd;
-	uint8_t cpu_count, cache_count, dimm_count, gpu_count;
+	uint8_t type_count, cache_count, dimm_count, gpu_count;
+	uint16_t current_cpu_count, all_cpu_count, current_core_id;
 	double  bus_freq, cpu_min_mult, cpu_max_mult;
 	bool    reload;
 
@@ -313,8 +320,8 @@ typedef struct
 typedef struct
 {
 	bool     cpuid_decimal, color, verbose, debug, issue, with_daemon, debug_database, freq_fallback;
-	uint8_t  selected_page, selected_core, bw_test, selected_gpu;
-	uint16_t output_type, refr_time;
+	uint8_t  selected_page, selected_type, bw_test, selected_gpu;
+	uint16_t selected_core, output_type, refr_time;
 	enum EnOptKeymap keymap;
 } Options;
 
@@ -333,7 +340,7 @@ typedef struct
 } PrefixUnit;
 
 extern Options *opts;
-
+extern bool __sigabrt_received;
 
 /***************************** Defined in main.c *****************************/
 
@@ -381,7 +388,13 @@ int load_module(char *module, int *fd);
 
 /* Get a filename located in a directory corresponding to given request */
 enum RequestSensor { RQT_CPU_TEMPERATURE, RQT_CPU_TEMPERATURE_OTHERS, RQT_CPU_VOLTAGE, RQT_GPU_TEMPERATURE, RQT_GPU_DRM, RQT_GPU_HWMON };
-int request_sensor_path(char *base_dir, char **cached_path, enum RequestSensor which);
+int request_sensor_path(uint16_t current_core_id, char *base_dir, char **cached_path, enum RequestSensor which);
+
+/* Get CPU core type name depending on CPU purpose */
+const char *get_core_type_name(uint8_t purpose);
+
+/* Change target core ID */
+void change_current_core_id(Labels *data);
 
 /* Start daemon in background */
 const char *start_daemon(bool graphical);
@@ -389,6 +402,9 @@ const char *start_daemon(bool graphical);
 /* Check if daemon is running */
 bool daemon_is_alive(void);
 
+/* Change CPU core affinity */
+bool set_cpu_affinity(uint16_t logical_cpu);
+
 
 /***************************** External headers *****************************/
 
