@@ -64,6 +64,7 @@ const Technology_DB technology_intel[] =
 	{  7,          23,          -1,          45 }, // C2 Wolfdale / Yorkfield / Penryn
 	{  7,          55,          -1,          22 }, // Atom Bay Trail
 	{  7,          71,          -1,          14 }, // Broadwell
+	{  7,         151,          -1,           7 }, // Alder Lake-P
 	{  7,         167,          -1,          14 }, // Rocket Lake
 	{  8,           0,           0,         180 }, // PIII Coppermine-T
 	{  8,           8,          -1,         180 }, // PIII Coppermine
@@ -73,6 +74,7 @@ const Technology_DB technology_intel[] =
 	{ 10,          42,          -1,          32 }, // Sandy Bridge
 	{ 10,          58,          -1,          22 }, // Ivy Bridge
 	{ 10,         122,          -1,          14 }, // Gemini Lake
+	{ 10,         154,          -1,           7 }, // Alder Lake-S
 	{ 11,          11,          -1,         130 }, // PIII Tualatine
 	{ 12,          28,          -1,          45 }, // Atom Diamondville / Pineview / Silverthorne
 	{ 12,          44,          -1,          32 }, // Westmere
@@ -132,15 +134,18 @@ const Technology_DB technology_amd[] =
 	{ -1,           1,          23,          14 }, // Zen (Summit Ridge/Whitehaven/Naples)
 	{ -1,          17,          23,          14 }, // Zen (Raven Ridge)
 	{ -1,           8,          23,          12 }, // Zen+ (Pinnacle Ridge/Colfax)
+	{ -1,          32,          23,          14 }, // Zen (Dali)
 	{ -1,          24,          23,          12 }, // Zen+ (Picasso)
 	{ -1,          49,          23,           7 }, // Zen 2 (Rome/Castle Peak)
 	{ -1,          96,          23,           7 }, // Zen 2 (Renoir)
 	{ -1,         104,          23,           7 }, // Zen 2 (Lucienne)
 	{ -1,         113,          23,           7 }, // Zen 2 (Matisse)
-	{ -1,          33,          25,           7 }, // Zen 3 (Vermeer)
+	{ -1,         144,          23,           7 }, // Zen 2 (Custom APU for Steam Deck)
+	{ -1,          33,          25,           7 }, // Zen 3 (Vermeer/Warhol)
 	{ -1,          80,          25,           7 }, // Zen 3 (Cezanne)
 	{ -1,           1,          25,           7 }, // Zen 3 (Milan)
-
+	{ -1,          68,          25,           7 }, // Zen 3 (Rembrandt)
+	{ -1,          97,          25,           5 }, // Zen 4 (Raphael)
 	{ -2,          -2,          -2,          -2 }
 	//Model        E. Model     E. Family   Process
 };
@@ -168,7 +173,8 @@ const Package_DB package_intel[] =
 	{ NULL,                             "Intel(R) Xeon(R) CPU E31275",      "LGA 1155"       },
 	{ NULL,                             "Intel(R) Core(TM) i7-2860QM CPU",  "rPGA 988B"      },
 	{ NULL,                             "Intel(R) Core(TM) i7-3740QM CPU",  "rPGA 988B"      },
-	{ NULL,                             "Intel(R) Core(TM) i5-4300U CPU",   "BGA 1168"       },
+	{ NULL,                             "Intel(R) Core(TM) i5-4300U CPU",   "FCBGA 1168"     },
+	{ NULL,                             "Intel(R) Core(TM) i7-4600U CPU",   "FCBGA 1168"     },
 	{ NULL,                             "Intel(R) Core(TM) i7-5775C CPU",   "LGA 1150"       },
 	{ NULL,                             "Intel(R) Core(TM) i7-6560U CPU",   "FCBGA 1356"     },
 	{ NULL,                             "Intel(R) Core(TM) i7-7300U CPU",   "FCBGA 1356"     },
@@ -176,10 +182,17 @@ const Package_DB package_intel[] =
 	{ NULL,                             "Intel(R) Core(TM) i7-8350U CPU",   "FCBGA 1356"     },
 	{ NULL,                             "Intel(R) Core(TM) i7-8550U CPU",   "FCBGA 1356"     },
 	{ NULL,                             "Intel(R) Core(TM) i7-8650U CPU",   "FCBGA 1356"     },
+	{ NULL,                             "Intel(R) Core(TM) i5-9300H CPU",   "FCBGA 1440"     },
 	{ NULL,                             "Intel(R) Core(TM) i9-9900K CPU",   "LGA 1151"       },
 	{ NULL,                             "Intel(R) Core(TM) i5-1135G7",      "FCBGA 1449"     },
 	{ NULL,                             "Intel(R) Core(TM) i7-1165G7",      "FCBGA 1449"     },
 	{ NULL,                             "Intel(R) Core(TM) i7-11700K",      "LGA 1200"       },
+	{ NULL,                             "Intel(R) Core(TM) i3-1220P",       "FCBGA 1744"     },
+	{ NULL,                             "Intel(R) Core(TM) i5-12400",       "LGA 1700"       },
+	{ NULL,                             "Intel(R) Core(TM) i7-12700H",      "FCBGA 1744"     },
+	{ NULL,                             "Intel(R) Core(TM) i7-12700KF",     "LGA 1700"       },
+	{ NULL,                             "Intel(R) Core(TM) i9-12900K",      "LGA 1700"       },
+	{ NULL,                             "Intel(R) Core(TM) i9-12900HK",     "FCBGA 1744"     },
 	{ NULL,                             NULL,                               NULL             }
 	//Codename                          Model                               Socket
 };
@@ -216,6 +229,7 @@ const Package_DB package_amd[] =
 	{ "Cezanne",                        NULL,            "FP6 (BGA-1140)"   },
 	{ "Vermeer",                        NULL,            "AM4 (PGA-1331)"   },
 	{ "Milan",                          NULL,            "SP3 (LGA-4094)"   },
+	{ "Raphael",                        NULL,            "AM5 (LGA-1718)"   },
 	{ NULL,                             NULL,            NULL               }
 	//Codename                          Model            Socket
 };
