@@ -47,7 +47,7 @@ static const char *objectcpu[LASTCPU] =
 	"proc_vendor", "proc_cdename", "proc_pkg", "proc_tech", "proc_volt", "proc_spec", "proc_fam", "proc_extfam", "proc_mod", "proc_extmod", "proc_temp", "proc_step", "proc_instr",
 	"clock_core", "clock_mult", "clock_bus", "clock_usage",
 	"cache_l1d", "cache_l1i", "cache_l2", "cache_l3",
-	"trg_sock", "trg_core", "trg_thrd"
+	"trg_core", "trg_thrd"
 };
 
 /* Tab Caches */
@@ -89,7 +89,7 @@ static const char *objectsys_bar[LASTBAR] =
 /* Tab Graphics */
 static const char *objectgpu[GPUFIELDS] =
 {
-	"card0_vend", "card0_driver", "card0_umd", "card0_mod", "card0_comp_unit", "card0_did_rid", "card0_pcie", "card0_temp", "card0_usage", "card0_gvolt", "card0_gpwr", "card0_gclk", "card0_mclk", "card0_vram_used", "card0_rebar"
+	"card0_vend", "card0_driver", "card0_umd", "card0_mod", "card0_comp_unit", "card0_did_rid", "card0_vbios_ver", "card0_pcie", "card0_temp", "card0_usage", "card0_gvolt", "card0_gpwr", "card0_gclk", "card0_mclk", "card0_vram_used", "card0_rebar", "card0_vkrt", "card0_gl_ver", "card0_vk_ver", "card0_cl_ver"
 };
 
 /* Tab Bench */
