@@ -44,6 +44,7 @@
 #define LOG_FILE "/tmp/cpu-x.log"
 
 Options *opts;
+bool __sigabrt_received = false;
 
 
 /************************* Arrays management functions *************************/
@@ -83,9 +84,8 @@ static void labels_setname(Labels *data)
 	asprintf(&data->tab_cpu[NAME][LEVEL2],          _("Level 2"));
 	asprintf(&data->tab_cpu[NAME][LEVEL3],          _("Level 3"));
 
-	asprintf(&data->tab_cpu[NAME][SOCKETS],         _("Socket(s)"));
-	asprintf(&data->tab_cpu[NAME][CORES],           _("Core(s)"));
-	asprintf(&data->tab_cpu[NAME][THREADS],         _("Thread(s)"));
+	asprintf(&data->tab_cpu[NAME][CORES],           _("Cores"));
+	asprintf(&data->tab_cpu[NAME][THREADS],         _("Threads"));
 
 	/* Caches tab */
 	asprintf(&data->objects[TABCACHES], _("Caches")); // Tab label
@@ -151,6 +151,7 @@ static void labels_setname(Labels *data)
 		asprintf(&data->tab_graphics[NAME][GPU1MODEL       + i], _("Model"));
 		asprintf(&data->tab_graphics[NAME][GPU1CU          + i], _("Compute Unit"));
 		asprintf(&data->tab_graphics[NAME][GPU1DIDRID      + i], _("DeviceID"));
+		asprintf(&data->tab_graphics[NAME][GPU1VBIOS       + i], _("VBIOS Version"));
 		asprintf(&data->tab_graphics[NAME][GPU1PCIE        + i], _("Interface"));
 		asprintf(&data->tab_graphics[NAME][GPU1TEMPERATURE + i], _("Temperature"));
 		asprintf(&data->tab_graphics[NAME][GPU1USAGE       + i], _("Usage"));
@@ -160,6 +161,10 @@ static void labels_setname(Labels *data)
 		asprintf(&data->tab_graphics[NAME][GPU1MEMCLOCK    + i], _("Memory clock"));
 		asprintf(&data->tab_graphics[NAME][GPU1MEMUSED     + i], _("Memory Used"));
 		asprintf(&data->tab_graphics[NAME][GPU1REBAR       + i], _("Resizable BAR"));
+		asprintf(&data->tab_graphics[NAME][GPU1VKRT        + i], _("Vulkan RT"));
+		asprintf(&data->tab_graphics[NAME][GPU1GLVER       + i], _("OpenGL Version"));
+		asprintf(&data->tab_graphics[NAME][GPU1VKVER       + i], _("Vulkan Version"));
+		asprintf(&data->tab_graphics[NAME][GPU1CLVER       + i], _("OpenCL Version"));
 	}
 	asprintf(&data->objects[FRAMCARDS], _("Cards")); // Frame label
 
@@ -236,7 +241,7 @@ static void dump_data(Labels *data)
 		{ NO_CPU,         VENDOR,       FRAMPROCESSOR       },
 		{ NO_CPU,         CORESPEED,    FRAMCLOCKS          },
 		{ NO_CPU,         LEVEL1D,      FRAMCACHE           },
-		{ NO_CPU,         SOCKETS,      -1                  },
+		{ NO_CPU,         CORES,        -1                  },
 		{ NO_CACHES,      L1SIZE,       FRAML1CACHE         },
 		{ NO_CACHES,      L2SIZE,       FRAML2CACHE         },
 		{ NO_CACHES,      L3SIZE,       FRAML3CACHE         },
@@ -342,6 +347,7 @@ static const struct
 	{ HAS_BANDWIDTH,   'B', "bandwidth",     no_argument,       N_("Run embedded command bandwidth and exit")                  },
 	{ true,            'r', "refresh",       required_argument, N_("Set custom time between two refreshes (in seconds)")       },
 	{ true,            't', "tab",           required_argument, N_("Set default tab (integer)")                                },
+	{ HAS_LIBCPUID,    'p', "type",          required_argument, N_("Select core type to monitor (integer)")                    },
 	{ HAS_LIBCPUID,    'c', "core",          required_argument, N_("Select CPU core to monitor (integer)")                     },
 	{ HAS_BANDWIDTH,   'b', "cachetest",     required_argument, N_("Set custom bandwidth test for CPU caches speed (integer)") },
 	{ HAS_LIBPCI,      'g', "gpu",           required_argument, N_("Select default graphic card (integer)")                    },
@@ -430,6 +436,9 @@ static void version(bool full_header)
 		{ HAS_LIBCPUID,    "LIBCPUID",    LIBCPUID_VERSION    },
 		{ HAS_LIBPCI,      "LIBPCI",      LIBPCI_VERSION      },
 		{ HAS_LIBGLFW,     "LIBGLFW",     LIBGLFW_VERSION     },
+		{ HAS_Vulkan,      "VULKAN",      Vulkan_VERSION      },
+		{ HAS_OpenCL,      "OPENCL",      OpenCL_VERSION      },
+		{ HAS_LIBPROC2,    "LIBPROC2",    LIBPROC2_VERSION    },
 		{ HAS_LIBPROCPS,   "LIBPROCPS",   LIBPROCPS_VERSION   },
 		{ HAS_LIBSTATGRAB, "LIBSTATGRAB", LIBSTATGRAB_VERSION },
 		{ HAS_DMIDECODE,   "DMIDECODE",   DMIDECODE_VERSION   },
@@ -511,8 +520,8 @@ static void parse_arguments(int argc_orig, char *argv_orig[])
 	j = 0;
 	for(i = 0; cpux_options[i].long_opt != NULL; i++)
 	{
-		while(!cpux_options[i].has_mod)
-			i++;
+		if(!cpux_options[i].has_mod)
+			continue;
 		longopts[j++] = (struct option) { .name = cpux_options[i].long_opt, .has_arg = cpux_options[i].need_arg, .flag = 0, .val = cpux_options[i].short_opt };
 		snprintf(shortopt, SHORT_OPT_SIZE, "%c%c", cpux_options[i].short_opt, cpux_options[i].need_arg ? ':' : '\0');
 		strncat(shortopts, shortopt, SHORT_OPTS_SIZE - 1);
@@ -557,6 +566,11 @@ static void parse_arguments(int argc_orig, char *argv_orig[])
 				if(NO_CPU < tmp_arg && tmp_arg <= NO_ABOUT)
 					opts->selected_page = tmp_arg;
 				break;
+			case 'p':
+				tmp_arg = atoi(optarg);
+				if(tmp_arg >= 0)
+					opts->selected_type = tmp_arg;
+				break;
 			case 'c':
 				tmp_arg = atoi(optarg);
 				if(tmp_arg >= 0)
@@ -610,7 +624,6 @@ static void parse_arguments(int argc_orig, char *argv_orig[])
 					opts->issue       = true;
 					opts->output_type = OUT_DUMP;
 					setlocale(LC_ALL, "C");
-					setenv("CPUX_DAEMON_DEBUG", "1", 1);
 					unlink(LOG_FILE);
 					freopen(LOG_FILE, "a", stdout);
 					setvbuf(stdout, NULL, _IONBF, 0);
@@ -649,8 +662,7 @@ static void parse_arguments(int argc_orig, char *argv_orig[])
 
 /************************* Main-related functions *************************/
 
-/* Action on SIGSEV/SIGFPE */
-static void sighandler(int signum)
+static void common_sighandler(int signum, bool need_stop)
 {
 	int bt_size, i;
 	char **bt_syms, *buff = NULL;
@@ -661,8 +673,11 @@ static void sighandler(int signum)
 	bt_syms = backtrace_symbols(bt, bt_size);
 
 	/* Print the backtrace */
-	MSG_STDERR(_("\n%sOops, something was wrong! %s has received signal %d (%s) and has crashed.%s"),
-	           BOLD_RED, PRGNAME, signum, strsignal(signum), DEFAULT);
+	if(need_stop)
+		fprintf(stderr, "%s", colorized_msg(BOLD_RED, _("\nOops, something was wrong! %s has received signal %d (%s) and has crashed."), PRGNAME, signum, strsignal(signum)));
+	else
+		fprintf(stderr, "%s", colorized_msg(BOLD_RED, _("\nOops, something was wrong! %s has received signal %d (%s) and is trying to recover."), PRGNAME, signum, strsignal(signum)));
+
 	MSG_STDERR("%s", "========================= Backtrace =========================");
 	PRGINFO(stderr);
 	for(i = 1; i < bt_size; i++)
@@ -676,13 +691,32 @@ static void sighandler(int signum)
 		free(buff);
 	}
 	MSG_STDERR("%s\n", "======================== End Backtrace =======================");
-	MSG_STDERR("%s", _("You can open a new issue here, by filling the template as requested:"));
-	MSG_STDERR("%s\n", ISSUEURL);
+	if(need_stop)
+	{
+		MSG_STDERR("%s", _("You can open a new issue here, by filling the template as requested:"));
+		MSG_STDERR("%s\n", ISSUEURL);
+	}
 
 	/* Stop program */
 	free(bt_syms);
-	signal(signum, SIG_DFL);
-	kill(getpid(), signum);
+	if(need_stop)
+	{
+		signal(signum, SIG_DFL);
+		kill(getpid(), signum);
+	}
+}
+
+/* Action on SIGILL/SIGSEV/SIGFPE */
+static void sighandler_fatal(int signum)
+{
+	common_sighandler(signum, true);
+}
+
+/* Action on SIGABRT */
+static void sighandler_abrt(int signum)
+{
+	__sigabrt_received = true;
+	common_sighandler(signum, false);
 }
 
  /* Enable internationalization support */
@@ -726,10 +760,13 @@ int main(int argc, char *argv[])
 		.tab_bench       = { { NULL } },
 		.cpu_freq        = 0,
 		.socket_fd       = -1,
-		.cpu_count       = 0,
+		.type_count      = 0,
 		.cache_count     = 0,
 		.dimm_count      = 0,
 		.gpu_count       = 0,
+		.current_cpu_count = 0,
+		.all_cpu_count   = 0,
+		.current_core_id = 0,
 		.bus_freq        = 0.0,
 		.cpu_min_mult    = 0.0,
 		.cpu_max_mult    = 0.0,
@@ -737,10 +774,7 @@ int main(int argc, char *argv[])
 	};
 	data->l_data = &(LibcpuidData)
 	{
-		.cpu_vendor_id  = -1,
-		.cpu_model      = -1,
-		.cpu_ext_model  = -1,
-		.cpu_ext_family = -1,
+		.change_type    = false,
 		.cpuid_raw_file = NULL
 	};
 	data->w_data = &(BandwidthData)
@@ -783,6 +817,7 @@ int main(int argc, char *argv[])
 		.debug_database = false,
 		.freq_fallback  = false,
 		.selected_page  = 0,
+		.selected_type  = 0,
 		.selected_core  = 0,
 		.bw_test        = 0,
 		.selected_gpu   = 0,
@@ -793,9 +828,10 @@ int main(int argc, char *argv[])
 #if HAS_GETTEXT
 	set_locales();
 #endif /* HAS_GETTEXT */
-	signal(SIGSEGV, sighandler);
-	signal(SIGFPE,  sighandler);
-	signal(SIGABRT, sighandler);
+	signal(SIGILL,  sighandler_fatal);
+	signal(SIGSEGV, sighandler_fatal);
+	signal(SIGFPE,  sighandler_fatal);
+	signal(SIGABRT, sighandler_abrt);
 
 	/* Parse options */
 #if HAS_GTK
